@@ -1,7 +1,7 @@
 """
 Type annotations for sagemaker-a2i-runtime service type definitions.
 
-[Open documentation](./type_defs.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/type_defs.html)
 
 Usage::
 
